import { useEffect, useState } from "react";
import useSDKFactory from "./useSDKFactory";
import { UseCase, PassListenable, RRListenable, SRListenable, } from "@inkerlabs/sdk";
export default function useWhiteListTicketsFactory(useCase) {
    return function useWhiteListTickets(privateSales) {
        var sdk = useSDKFactory()();
        var _a = useState(undefined), tickets = _a[0], setTickets = _a[1];
        var _b = useState(undefined), error = _b[0], setError = _b[1];
        var id;
        var cb = function (err, _tickets) {
            setError(err);
            setTickets(_tickets);
        };
        var unlisten = function () {
            switch (useCase) {
                case UseCase.PASS:
                    var passSDK = sdk;
                    if (id) {
                        passSDK.unlisten(id, PassListenable.WHITELIST_TICKETS);
                    }
                    break;
                case UseCase.RR:
                    var rrSDK = sdk;
                    if (id) {
                        rrSDK.unlisten(id, RRListenable.WHITELIST_TICKETS);
                    }
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    if (id) {
                        srSDK.unlisten(id, SRListenable.WHITELIST_TICKETS);
                    }
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        };
        useEffect(function () {
            unlisten();
            if (!privateSales) {
                cb(undefined, undefined);
                return;
            }
            switch (useCase) {
                case UseCase.PASS:
                    console.log("HELLO", privateSales);
                    var passSDK = sdk;
                    id = passSDK.listen(PassListenable.WHITELIST_TICKETS, cb);
                    break;
                case UseCase.RR:
                    var rrSDK = sdk;
                    id = rrSDK.listen(RRListenable.WHITELIST_TICKETS, cb);
                    break;
                case UseCase.SR:
                    var srSDK = sdk;
                    id = srSDK.listen(SRListenable.WHITELIST_TICKETS, cb);
                    break;
                default:
                    throw new Error("Unsupported use case ".concat(useCase));
            }
        }, [privateSales]);
        // Emulate componentWillUnmount
        useEffect(function () {
            return function () {
                unlisten();
            };
        }, []);
        return [tickets, error];
    };
}
